Author: LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
Description: In late 2021 the LANDFIRE (LF) team responded to feedback and created new topographic products (Elevation, Slope, and Aspect) for the Conterminous US, Alaska, Hawaii, and Puerto Rico and the Virgin Islands to release in early 2022. To create the new LF 2020 Elevation product, the 1 arc-second (approximately 30 meters) Digital Elevation Model (DEM) tiles were downloaded from The National Map (TNM) Viewer (v2.0) on Nov. 09, 2021. The tiles were mosaicked in the native coordinate system (GCS_North_American_1983 WKID: 4269 Authority: EPSG) and format (32-float). The file was projected to NAD_1983_Contiguous_USA_Albers (WKID: 5070 Authority: EPSG) using the Project Raster tool in ArcGIS Desktop 10.6.1 (ArcGIS) with Bilinear Interpolation re-sampling method, cell size and spacing set to the LF grid. This file was used to calculate aspect and slope. The file was then converted to Signed 16-bit using the Copy Raster tool in ArcGIS and then clipped to the LF boundary using the Extract by Mask t [cell cut: 1192 characters, first 1000 kept]
Keywords: biota
Date: 20220131

# LANDFIRE 2020 Elevation (Elev) CONUS

Metadata also available as

# Metadata:

- Identification_Information
- Data_Quality_Information
- Spatial_Data_Organization_Information
- Spatial_Reference_Information
- Entity_and_Attribute_Information
- Distribution_Information
- Metadata_Reference_Information

Identification_Information:
  Citation:
    Citation_Information:
      Originator:
        LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Publication_Date: 20220131
      Title: LANDFIRE 2020 Elevation (Elev) CONUS
      Edition: LF 2020
      Geospatial_Data_Presentation_Form: raster digital data
      Publication_Information:
        Publication_Place: Sioux Falls, SD
        Publisher:
          Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Online_Linkage: https://www.landfire.gov
  Description:
    Abstract:
      In late 2021 the LANDFIRE (LF) team responded to feedback and created new topographic products (Elevation, Slope, and Aspect) for the Conterminous US, Alaska, Hawaii, and Puerto Rico and the Virgin Islands to release in early 2022. To create the new LF 2020 Elevation product, the 1 arc-second (approximately 30 meters) Digital Elevation Model (DEM) tiles were downloaded from The National Map (TNM) Viewer (v2.0) on Nov. 09, 2021. The tiles were mosaicked in the native coordinate system (GCS_North_American_1983 WKID: 4269 Authority: EPSG) and format (32-float). The file was projected to NAD_1983_Contiguous_USA_Albers (WKID: 5070 Authority: EPSG) using the Project Raster tool in ArcGIS Desktop 10.6.1 (ArcGIS) with Bilinear Interpolation re-sampling method, cell size and spacing set to the LF grid. This file was used to calculate aspect and slope. The file was then converted to Signed 16-bit using the Copy Raster tool in ArcGIS and then clipped to the LF boundary using the Extract by Mask tool in ArcGIS. Several NoData areas were assigned value zero (0) that overlap the LF data extent which includes a 3 nautical mile buffer along coastal areas. Otherwise, -9999 indicates NoData.
    Purpose:
      LANDFIRE 2020 Update (LF 2020) represents circa 2020 ground conditions and is designed to produce vegetation, disturbance, and fuels products that inform wildland fire and ecological decision systems. LF 2020 is an update to the new base map, LF 2016 Remap (LF Remap), which improved past methodologies and processes to incorporate current satellite imagery, contemporary data sources, and the latest software and hardware technologies. LF 2020 utilizes the most recent and relevant geospatial data available to offer products that reflect current conditions.
      LF 2020 products are designed to facilitate national and regional level strategic fire and resource management planning and reporting of management activities. The principal purposes of the products include providing, 1) national level, landscape scale geospatial products to support fire and fuels management planning, and 2) consistent fuels products to support fire planning, analysis, and budgeting to evaluate fire management alternatives.
      Products are created at a 30 meter raster; however, the applicability of products varies by location and specific use. LF products were designed to support 1) national (all states) strategic planning, 2) regional (single large states or groups of smaller states), and 3) strategic/tactical planning for large sub regional landscapes and Fire Management Units (FMUs) (such as significant portions of states or multiple federal administrative entities). The applicability of LF products to support fire and land management planning on smaller areas will vary by product, location, and specific use. Managers and planners must evaluate LF products according to the scale and requirements specific to their needs.
    Supplemental_Information: LF 2020 Elevation products are in meters above sea level.
  Time_Period_of_Content:
    Time_Period_Information:
      Single_Date/Time:
        Calendar_Date: 2020
    Currentness_Reference: ground condition
  Status:
    Progress: Complete
    Maintenance_and_Update_Frequency: Biennially
  Spatial_Domain:
    Bounding_Coordinates:
      West_Bounding_Coordinate: -72.6555
      East_Bounding_Coordinate: -72.4909
      North_Bounding_Coordinate: 44.4821
      South_Bounding_Coordinate: 44.3413
  Keywords:
    Theme:
      Theme_Keyword_Thesaurus: ISO 19115 Topic Category
      Theme_Keyword: biota
    Theme:
      Theme_Keyword_Thesaurus: USGS Thesaurus
      Theme_Keyword: fires
      Theme_Keyword: hazard preparedness
      Theme_Keyword: remote sensing
      Theme_Keyword: image collections
      Theme_Keyword: geospatial datasets
      Theme_Keyword: geographic information systems
    Theme:
      Theme_Keyword_Thesaurus: None
      Theme_Keyword: raster digital data
      Theme_Keyword: Elevation
      Theme_Keyword: U.S. Geological Survey (USGS)
      Theme_Keyword: LANDFIRE 2020
      Theme_Keyword: topography
      Theme_Keyword: topo
    Place:
      Place_Keyword_Thesaurus: Common geographic areas
      Place_Keyword: US
      Place_Keyword: CONUS
      Place_Keyword: United States
      Place_Keyword: Continental U.S.
      Place_Keyword: Conterminous United States
  Access_Constraints: None
  Use_Constraints: None
  Point_of_Contact:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization:
          LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Contact_Position: Customer Service Representative
      Contact_Address:
        Address_Type: physical
        Address: 47914 252nd Street
        City: Sioux Falls
        State_or_Province: SD
        Postal_Code: 57198
        Country: U.S.
      Contact_Voice_Telephone: 605-594-6151
      Contact_Electronic_Mail_Address: helpdesk@landfire.gov
  Data_Set_Credit:
    These products were created by the LF team at USGS EROS, Sioux Falls, SD. Refer to the contact information throughout this metadata to contact the LF team.
  Security_Information:
    Security_Classification_System: None in place
    Security_Classification: Unclassified
    Security_Handling_Description:
      If there is ever doubt, contact the LF Help Desk at helpdesk@landfire.gov
  Native_Data_Set_Environment: Microsoft Windows 10; ESRI ArcCatalog 10.6.1
  Cross_Reference:
    Citation_Information:
      Originator: USGS
      Publication_Date: 2021
      Title: USGS National Geospatial Program The National Map Viewer
      Geospatial_Data_Presentation_Form: raster digital data
      Other_Citation_Details:
        TNM Viewer v2.0
        National Boundaries Dataset, 3DEP Elevation Program, Geographic Names Information System, National Hydrography Dataset, National Structures Dataset, and National Transportation Dataset
      Online_Linkage:
        https://www.usgs.gov/programs/national-geospatial-program/national-map
      Online_Linkage: https://www.usgs.gov/national-hydrography
      Online_Linkage: https://www.usgs.gov/3d-elevation-program
      Online_Linkage: https://apps.nationalmap.gov/datasets/
  Cross_Reference:
    Citation_Information:
      Originator: USGS
      Publication_Date: 2009
      Title: USGS Global Ecosystems
      Geospatial_Data_Presentation_Form: publication
      Online_Linkage:
        https://www.usgs.gov/centers/geosciences-and-environmental-change-science-center/science/global-ecosystems
  Cross_Reference:
    Citation_Information:
      Originator: Collin G. Homer
      Originator: Joyce A. Fry
      Originator: Christopher A. Barnes
      Publication_Date: 2012
      Title: The National Land Cover Database
      Geospatial_Data_Presentation_Form: publication
      Publication_Information:
        Publication_Place: n/a
        Publisher: US Geological Survey
      Online_Linkage: https://doi.org/10.3133/fs20123020
  Cross_Reference:
    Citation_Information:
      Originator: NOAA
      Publication_Date: 1998
      Title:
        NOAA National Centers for Environmental Information U.S. Coastal Relief Model
      Geospatial_Data_Presentation_Form: publication
      Online_Linkage: https://www.ngdc.noaa.gov/mgg/coastal/crm.html
  Cross_Reference:
    Citation_Information:
      Originator: US Census Bureau
      Publication_Date: 2021
      Title: U.S. Census Bureau TIGER/Line data
      Geospatial_Data_Presentation_Form: publication
      Online_Linkage:
        https://www.census.gov/geographies/mapping-files/time-series/geo/tiger-geodatabase-file.html

Data_Quality_Information:
  Attribute_Accuracy:
    Attribute_Accuracy_Report:
      Products were tested to ensure that each attribute is represented consistently across all data sets. Attributes were not validated against in person observations.
  Logical_Consistency_Report:
    The products were pixel "truth" tested for consistency of land or water characteristics across all products.
  Completeness_Report:
    Products were formally tested to ensure that valid data was produced for all pixels. Each product was then validated and tested for duplicates, omissions, and errors.
  Lineage:
    Process_Step:
      Process_Description:
        Beginning in 2016 LF Remap products were created using recent advances in image compositing, tiling algorithms, and faster computing hardware to ensure that LF products remained relevant. LF Remap leveraged the Landsat archive, lidar data, and user contributed field plot data compiled into the LF Reference Database (LFRDB), to create new base map vegetation products. Reference resources included, but were not limited to, Forest Inventory and Analysis (FIA) program plot data (USFS https://fia.fs.fed.us/), Landsat Dynamic Surface Water Extent [(DSWE) USGS https://www.usgs.gov/landsat-missions], the National Land Cover Dataset [(NLCD) USGS https://www.mrlc.gov/data], and National Agricultural Statistics Service [(NASS) USDA - https://www.nass.usda.gov/]. To read more about LF reference resources go to https://www.landfire.gov/reference.php. Information about LF Remap product testing is available by request or via the website at https://www.landfire.gov.
      Process_Date: 20220131

Spatial_Data_Organization_Information:
  Direct_Spatial_Reference_Method: Raster
  Raster_Object_Information:
    Raster_Object_Type: Grid Cell
    Row_Count: 20729
    Column_Count: 24853

Spatial_Reference_Information:
  Horizontal_Coordinate_System_Definition:
    Planar:
      Map_Projection:
        Map_Projection_Name: Albers Conical Equal Area
        Albers_Conical_Equal_Area:
          Standard_Parallel: 29.5
          Standard_Parallel: 45.5
          Longitude_of_Central_Meridian: -96.0
          Latitude_of_Projection_Origin: 23.0
          False_Easting: 0
          False_Northing: 0
      Planar_Coordinate_Information:
        Planar_Coordinate_Encoding_Method: row and column
        Coordinate_Representation:
          Abscissa_Resolution: 30
          Ordinate_Resolution: 30
        Planar_Distance_Units: meters
    Geodetic_Model:
      Horizontal_Datum_Name: North American Datum of 1983 (NAD 83)
      Ellipsoid_Name: Geodetic Reference System 1980
      Semi-major_Axis: 6378137.000000
      Denominator_of_Flattening_Ratio: 298.257222
  Vertical_Coordinate_System_Definition:

Entity_and_Attribute_Information:
  Overview_Description:
    Entity_and_Attribute_Overview:
      LANDFIRE (LF) 2020 Elevation CONUS. An Attribute Table is included with each product download as a .dbf and embedded in the metadata. The Attribute Data Dictionary (ADD) can be found at https://www.landfire.gov/.
    Entity_and_Attribute_Detail_Citation: https://landfire.gov/elevation.php

Distribution_Information:
  Distributor:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization:
          LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Contact_Position: Customer Service Representative
      Contact_Address:
        Address_Type: physical
        Address: 47914 252nd Street
        City: Sioux Falls
        State_or_Province: SD
        Postal_Code: 57198
        Country: U.S.
      Contact_Voice_Telephone: 605-594-6151
      Contact_Electronic_Mail_Address: helpdesk@landfire.gov
  Distribution_Liability:
    This product is reproduced from geospatial information prepared by the U.S. Department of the Interior (DOI) USGS EROS. By removing the contents of this package or taking receipt of these files via electronic file transfer methods, you understand that the data stored on this media can be updated at any time. Represented features may not be in an accurate geographic location. USGS EROS makes no expressed or implied warranty, including warranty of merchantability and fitness, with respect to the character, function, or capabilities of the data or their appropriateness for any user's purposes. USGS EROS reserves the right to correct, update, modify, or replace this geospatial information without notification.
  Standard_Order_Process:
    Digital_Form:
      Digital_Transfer_Information:
        Format_Name: ARCG
        Format_Version_Date: 20220131
        Format_Specification: LF 2020
      Digital_Transfer_Option:
        Online_Option:
          Computer_Contact_Information:
            Network_Address:
              Network_Resource_Name: https://www.landfire.gov
    Fees: none

Metadata_Reference_Information:
  Metadata_Date: 20220131
  Metadata_Contact:
    Contact_Information:
      Contact_Organization_Primary:
        Contact_Organization:
          LANDFIRE, Earth Resources Observation and Science Center (EROS), U.S. Geological Survey
      Contact_Position: Customer Service Representative
      Contact_Address:
        Address_Type: physical
        Address: 47914 252nd Street
        City: Sioux Falls
        State_or_Province: SD
        Postal_Code: 57198
        Country: U.S.
      Contact_Voice_Telephone: 605-594-6151
      Contact_Electronic_Mail_Address: helpdesk@landfire.gov
  Metadata_Standard_Name: FGDC Content Standard for Digital Geospatial Metadata
  Metadata_Standard_Version: FGDC-STD-001-1998
  Metadata_Time_Convention: local time
  Metadata_Security_Information:
    Metadata_Security_Classification_System: None
    Metadata_Security_Classification: Unclassified
    Metadata_Security_Handling_Description: None